/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.geronimo;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.net.URL;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Servlet implementation class for Servlet: BlockingServlet
 * 
 * @web.servlet name="BlockingServlet" display-name="BlockingServlet"
 * 
 * @web.servlet-mapping url-pattern="/sync"
 * 
 */
public class BlockingServlet extends HttpServlet {
    static final long serialVersionUID = 1L;

    private String remoteUrl;

    public void init() throws ServletException {
        getServletContext().log("getinit init");
        // Get the value of an initialization parameter
        remoteUrl = getServletConfig().getInitParameter("remoteUrl");
    }

    /**
     * Process the given Comet event.
     * 
     * @param event
     *            The Comet event that will be processed
     * @throws IOException
     * @throws ServletException
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {
        
        boolean debug = Boolean.parseBoolean(request.getParameter("debug"));
        boolean shortCircuit = Boolean.parseBoolean(request.getParameter("shortCircuit"));
        if (debug) {
            System.out.println("");
            System.out.println("Inside BlockingServlet.doGet()");
        }
        
        String sessionId = request.getSession(true).getId();


        if (!shortCircuit) {
            if (request.getParameter("remoteUrl") != null) {
                remoteUrl = request.getParameter("remoteUrl");
            }
    
            String remoteUri = request.getParameter("remoteUri");
            if (remoteUri == null) {
                remoteUri = "/remoteApp/page";
            }       
    
            String delay = request.getParameter("delay") == null ?
                    String.valueOf(Utils.generateRandomDelay()) :
                    request.getParameter("delay");
            
            String code = request.getParameter("code") == null ?
                    String.valueOf(Utils.generateRandomCode()) : 
                    request.getParameter("code");
            if (debug) {        
                System.out.println("sessionId:" + sessionId + "; delay:" + delay + "; code:" + code);
            }
            
            String url_string = remoteUrl + remoteUri + "?sessionId=" + sessionId + "&delay=" + delay + "&code=" + code;        
            URL url_connect = new URL(url_string);
            
            try {
                BufferedReader input = new BufferedReader(new InputStreamReader(url_connect.openStream()));
                String line = "";                       
                response.setContentType("text/html");
                PrintWriter out = response.getWriter();         
                while ((line = input.readLine()) != null) {             
                    out.println(line);
                }
                out.flush();
                out.close();
                input.close();
            }
            catch(IOException ex) {
                response.sendError(Integer.parseInt(code));         
            }
        } else {
            return;
        }
        
        if (debug) {
            System.out.println("doGet processed");
        }
    }
}