/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.javaee6.restfulorder.converter;

import java.net.URI;
import java.util.Collection;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlAttribute;
import java.util.ArrayList;
import org.apache.geronimo.samples.javaee6.restfulorder.entities.Restfulorder;

@XmlRootElement(name = "restfulorders")
public class RestfulordersConverter {
    private Collection<Restfulorder> entities;
    private Collection<RestfulorderConverter> items;
    private URI uri;
    private int expandLevel;
  
    /** Creates a new instance of RestfulordersConverter */
    public RestfulordersConverter() {
    }

    /**
     * Creates a new instance of RestfulordersConverter.
     *
     * @param entities associated entities
     * @param uri associated uri
     * @param expandLevel indicates the number of levels the entity graph should be expanded
     */
    public RestfulordersConverter(Collection<Restfulorder> entities, URI uri, int expandLevel) {
        this.entities = entities;
        this.uri = uri;
        this.expandLevel = expandLevel;
        getRestfulorder();
    }

    /**
     * Returns a collection of RestfulorderConverter.
     *
     * @return a collection of RestfulorderConverter
     */
    @XmlElement
    public Collection<RestfulorderConverter> getRestfulorder() {
        if (items == null) {
            items = new ArrayList<RestfulorderConverter>();
        }
        if (entities != null) {
            items.clear();
            for (Restfulorder entity : entities) {
                items.add(new RestfulorderConverter(entity, uri, expandLevel, true));
            }
        }
        return items;
    }

    /**
     * Sets a collection of RestfulorderConverter.
     *
     * @param a collection of RestfulorderConverter to set
     */
    public void setRestfulorder(Collection<RestfulorderConverter> items) {
        this.items = items;
    }

    /**
     * Returns the URI associated with this converter.
     *
     * @return the uri
     */
    @XmlAttribute
    public URI getUri() {
        return uri;
    }

    /**
     * Returns a collection Restfulorder entities.
     *
     * @return a collection of Restfulorder entities
     */
    @XmlTransient
    public Collection<Restfulorder> getEntities() {
        entities = new ArrayList<Restfulorder>();
        if (items != null) {
            for (RestfulorderConverter item : items) {
                entities.add(item.getEntity());
            }
        }
        return entities;
    }
}
