/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.javaee6.restfulorder.service;

import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.DELETE;
import javax.ws.rs.Produces;
import javax.ws.rs.Consumes;
import javax.ws.rs.QueryParam;
import javax.ws.rs.DefaultValue;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.UriInfo;
import javax.ws.rs.WebApplicationException;
import javax.persistence.NoResultException;
import javax.persistence.EntityManager;
import org.apache.geronimo.samples.javaee6.restfulorder.converter.RestfulorderConverter;
import javax.ejb.Stateless;
import org.apache.geronimo.samples.javaee6.restfulorder.entities.Restfulorder;


@Stateless
public class RestfulorderResource {
    @Context
    protected UriInfo uriInfo;
    protected EntityManager em;
    protected Integer id;
  
    /** Creates a new instance of RestfulorderResource */
    public RestfulorderResource() {
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public void setEm(EntityManager em) {
        this.em = em;
    }

    /**
     * Get method for retrieving an instance of Restfulorder identified by id in XML format.
     *
     * @param id identifier for the entity
     * @return an instance of RestfulorderConverter
     */
    @GET
    @Produces({"application/xml", "application/json"})
    public RestfulorderConverter get(@QueryParam("expandLevel")
                                     @DefaultValue("1")
    int expandLevel) {
        return new RestfulorderConverter(getEntity(), uriInfo.getAbsolutePath(), expandLevel);
    }

    /**
     * Put method for updating an instance of Restfulorder identified by id using XML as the input format.
     *
     * @param id identifier for the entity
     * @param data an RestfulorderConverter entity that is deserialized from a XML stream
     */
    @PUT
    @Consumes({"application/xml", "application/json"})
    public void put(RestfulorderConverter data) {
        updateEntity(getEntity(), data.resolveEntity(em));
    }

    /**
     * Delete method for deleting an instance of Restfulorder identified by id.
     *
     * @param id identifier for the entity
     */
    @DELETE
    public void delete() {
        deleteEntity(getEntity());
    }

    /**
     * Returns an instance of Restfulorder identified by id.
     *
     * @param id identifier for the entity
     * @return an instance of Restfulorder
     */
    protected Restfulorder getEntity() {
        try {
            return (Restfulorder) em.createQuery("SELECT e FROM Restfulorder e where e.id = :id").setParameter("id", id).getSingleResult();
        } catch (NoResultException ex) {
            throw new WebApplicationException(new Throwable("Resource for " + uriInfo.getAbsolutePath() + " does not exist."), 404);
        }
    }

    /**
     * Updates entity using data from newEntity.
     *
     * @param entity the entity to update
     * @param newEntity the entity containing the new data
     * @return the updated entity
     */
    private Restfulorder updateEntity(Restfulorder entity, Restfulorder newEntity) {
        entity = em.merge(newEntity);
        return entity;
    }

    /**
     * Deletes the entity.
     *
     * @param entity the entity to deletle
     */
    private void deleteEntity(Restfulorder entity) {
        em.remove(entity);
    }
}
