/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.geronimo.samples.javaee6.restfulorder.service;

import java.util.Collection;
import javax.ws.rs.Path;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Produces;
import javax.ws.rs.Consumes;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.DefaultValue;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.UriInfo;
import javax.persistence.EntityManager;
import org.apache.geronimo.samples.javaee6.restfulorder.converter.RestfulordersConverter;
import org.apache.geronimo.samples.javaee6.restfulorder.converter.RestfulorderConverter;
import javax.persistence.PersistenceContext;
import javax.ejb.Stateless;
import org.apache.geronimo.samples.javaee6.restfulorder.entities.Restfulorder;


@Path("/restfulorders/")
@Stateless
public class RestfulordersResource {
    @javax.ejb.EJB
    private RestfulorderResource restfulorderResource;
    @Context
    protected UriInfo uriInfo;
    @PersistenceContext(unitName = "RestfulProduct2PU")
    protected EntityManager em;
  
    /** Creates a new instance of RestfulordersResource */
    public RestfulordersResource() {
    }

    /**
     * Get method for retrieving a collection of Restfulorder instance in XML format.
     *
     * @return an instance of RestfulordersConverter
     */
    @GET
    @Produces({"application/xml", "application/json"})
    public RestfulordersConverter get(@QueryParam("start")
                                      @DefaultValue("0")
    int start, @QueryParam("max")
               @DefaultValue("10")
    int max, @QueryParam("expandLevel")
             @DefaultValue("1")
    int expandLevel, @QueryParam("query")
                     @DefaultValue("SELECT e FROM Restfulorder e")
    String query) {
        return new RestfulordersConverter(getEntities(start, max, query), uriInfo.getAbsolutePath(), expandLevel);
    }

    /**
     * Post method for creating an instance of Restfulorder using XML as the input format.
     *
     * @param data an RestfulorderConverter entity that is deserialized from an XML stream
     * @return an instance of RestfulorderConverter
     */
    @POST
    @Consumes({"application/xml", "application/json"})
    public Response post(RestfulorderConverter data) {
        System.out.println("before resolve,in post");
        Restfulorder entity = data.resolveEntity(em);
        createEntity(data.resolveEntity(em));
        return Response.created(uriInfo.getAbsolutePath().resolve(entity.getId() + "/")).build();
    }

    /**
     * Returns a dynamic instance of RestfulorderResource used for entity navigation.
     *
     * @return an instance of RestfulorderResource
     */
    @Path("{id}/")
    public RestfulorderResource getRestfulorderResource(@PathParam("id")
    Integer id) {
        restfulorderResource.setId(id);
        restfulorderResource.setEm(em);
        return restfulorderResource;
    }

    /**
     * Returns all the entities associated with this resource.
     *
     * @return a collection of Restfulorder instances
     */
    protected Collection<Restfulorder> getEntities(int start, int max, String query) {
        return em.createQuery(query).setFirstResult(start).setMaxResults(max).getResultList();
    }

    /**
     * Persist the given entity.
     *
     * @param entity the entity to persist
     */
    protected void createEntity(Restfulorder entity) {
        em.persist(entity);
    }
}
