/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var useWrapRestfulorders = true;

function Restfulorders(uri_) {
    this.uri = uri_;
    this.items = new Array();
    this.initialized = false;
}

Restfulorders.prototype = {

    getUri : function() {
        return this.uri;
    },

    getItems : function() {
        if(!this.initialized)
            this.init();
        return this.items;
    },

    addItem : function(item) {
        var remote = new RestfulordersRemote(this.uri);
        remote.postJson_(item.toString());
        this.items.push(item);
    },

    removeItem : function(item) {
        var status = item.delete_();
        if(status)
            this.init(); //re-read items
        return status;
    },

    init : function() {
        var remote = new RestfulordersRemote(this.uri);
        var c = remote.getJson_();
        if(c != -1) {
            var myObj = eval('('+c+')');
            var restfulorders = myObj.restfulorders;
            if(restfulorders == null || restfulorders == undefined || restfulorders['@uri'] == undefined) {
                restfulorders = myObj;
                useWrapRestfulorders = false;
            }
            this.items = new Array();
            var refs = restfulorders.restfulorder;
         
            if(refs != undefined) {
                if(refs.length == undefined) {
                    this.initChild(refs, 0);
                } else {
                    var j = 0;
                    for(j=0;j<refs.length;j++) {
                        var ref = refs[j];
                        this.initChild(ref, j);
                    }
                }
            } else {
                rjsSupport.debug('restfulorder is undefined, so skipping initChild for Restfulorders');
            }
            this.initialized = true;
        }
    },

    initChild : function(ref, j) {
        var uri2 = ref['@uri'];
        this.items[j] = new Restfulorder(uri2);
    },

    flush : function() {
        var remote = new RestfulordersRemote(this.uri);
        if(useWrapRestfulorders)
            remote.postJson_('{'+this.toString()+'}');
        else
            return remote.postJson_(this.toString());
    },

    flush : function(restfulorder) {
        var remote = new RestfulordersRemote(this.uri);
        if(useWrapRestfulorders)
            return remote.postJson_('{'+restfulorder.toString()+'}');
        else
            return remote.postJson_(restfulorder.toString());
    },

    toString : function() {
        if(!this.initialized)
            this.init();
        var s = '';
        var j = 0;
        if(this.items.length > 1)
            s = s + '[';
        for(j=0;j<this.items.length;j++) {
            var c = this.items[j];
            if(j<this.items.length-1)
                s = s + '{"@uri":"'+c.getUri()+'", "restfulorderId":"'+rjsSupport.findIdFromUrl(c.getUri())+'"},';
            else
                s = s + '{"@uri":"'+c.getUri()+'", "restfulorderId":"'+rjsSupport.findIdFromUrl(c.getUri())+'"}';
        }
        if(this.items.length > 1)
            s = s + ']';
        var myObj = '';
        if(s == '') {
            myObj = '{"@uri":"'+this.getUri()+'"}';
        } else {
            myObj =
            '{'+'"@uri":"'+this.getUri()+'",'+'"restfulorder":'+s+''+'}';
        }
        if(useWrapRestfulorders) {
            myObj = '"restfulorders":'+myObj;
        }
        return myObj;
    }

}

function RestfulordersRemote(uri_) {
    this.uri = uri_+'?expandLevel=0&start=0&max=50';
}

RestfulordersRemote.prototype = {

    /* Default getJson_() method used by init() method. Do not remove. */
    getJson_ : function() {
        return rjsSupport.get(this.uri, 'application/json');
    },
    /* Default postJson_() method used by flush() methods. Do not remove. */
    postJson_ : function(content) {
        return rjsSupport.post(this.uri, 'application/json', content);
    }
    ,
    getXml : function() {
        return rjsSupport.get(this.uri, 'application/xml');
    },

    getJson : function() {
        return rjsSupport.get(this.uri, 'application/json');
    },

    postXml : function(content) {
        return rjsSupport.post(this.uri, 'application/xml', content);
    },

    postJson : function(content) {
        return rjsSupport.post(this.uri, 'application/json', content);
    },

    getRestfulorderResource : function(id) {
        var link = new Restfulorder(this.uri+'/'+id);
        return link;
    }
}
